#if __GLASGOW_HASKELL__ >= 703
{-# LANGUAGE Safe #-}
#endif
{- |
Maintainer  : judah.jacobson@gmail.com
Stability   : experimental
Portability : portable (FFI)
-}
module System.Console.Terminfo(
    module System.Console.Terminfo.Base,
    module System.Console.Terminfo.Keys,
    module System.Console.Terminfo.Cursor,
    module System.Console.Terminfo.Effects,
    module System.Console.Terminfo.Edit,
    module System.Console.Terminfo.Color
    ) where

import System.Console.Terminfo.Base
import System.Console.Terminfo.Keys
import System.Console.Terminfo.Cursor
import System.Console.Terminfo.Edit
import System.Console.Terminfo.Effects
import System.Console.Terminfo.Color
